@@ -21,16 +21,14 @@ config etc/rc.d/rc.cups.new
 ( cd usr/bin ; ln -sf lpr-cups lpr )
 ( cd usr/bin ; rm -rf lprm )
 ( cd usr/bin ; ln -sf lprm-cups lprm )
-( cd usr/bin ; rm -rf disable )
-( cd usr/bin ; ln -sf ../sbin/accept disable )
 ( cd usr/bin ; rm -rf cancel )
 ( cd usr/bin ; ln -sf cancel-cups cancel )
-( cd usr/bin ; rm -rf enable )
-( cd usr/bin ; ln -sf ../sbin/accept enable )
 ( cd usr/bin ; rm -rf lpstat )
 ( cd usr/bin ; ln -sf lpstat-cups lpstat )
 ( cd usr/doc ; rm -rf cups )
-( cd usr/doc ; ln -sf cups-1.1.23 cups )
+( cd usr/doc ; ln -sf cups-1.2.4 cups )
+( cd usr/lib/cups/filter ; rm -rf rastertodymo )
+( cd usr/lib/cups/filter ; ln -sf rastertolabel rastertodymo )
 ( cd usr/lib/cups/backend ; rm -rf smb )
 ( cd usr/lib/cups/backend ; ln -sf /usr/bin/smbspool smb )
 ( cd usr/lib/cups/backend ; rm -rf http )
@@ -39,18 +37,6 @@ config etc/rc.d/rc.cups.new
 ( cd usr/lib ; ln -sf libcupsimage.so.2 libcupsimage.so )
 ( cd usr/lib ; rm -rf libcups.so )
 ( cd usr/lib ; ln -sf libcups.so.2 libcups.so )
-( cd usr/man/es/man1 ; rm -rf cancel.1.gz )
-( cd usr/man/es/man1 ; ln -sf lp.1.gz cancel.1.gz )
-( cd usr/man/es/man8 ; rm -rf reject.8.gz )
-( cd usr/man/es/man8 ; ln -sf accept.8.gz reject.8.gz )
-( cd usr/man/es/man8 ; rm -rf disable.8.gz )
-( cd usr/man/es/man8 ; ln -sf enable.8.gz disable.8.gz )
-( cd usr/man/fr/man1 ; rm -rf cancel.1.gz )
-( cd usr/man/fr/man1 ; ln -sf lp.1.gz cancel.1.gz )
-( cd usr/man/fr/man8 ; rm -rf reject.8.gz )
-( cd usr/man/fr/man8 ; ln -sf accept.8.gz reject.8.gz )
-( cd usr/man/fr/man8 ; rm -rf disable.8.gz )
-( cd usr/man/fr/man8 ; ln -sf enable.8.gz disable.8.gz )
 ( cd usr/man/man1 ; rm -rf lp.1.gz )
 ( cd usr/man/man1 ; ln -sf lp-cups.1.gz lp.1.gz )
 ( cd usr/man/man1 ; rm -rf lprm.1.gz )
@@ -61,17 +47,19 @@ config etc/rc.d/rc.cups.new
 ( cd usr/man/man1 ; ln -sf lpstat-cups.1.gz lpstat.1.gz )
 ( cd usr/man/man1 ; rm -rf lpq.1.gz )
 ( cd usr/man/man1 ; ln -sf lpq-cups.1.gz lpq.1.gz )
-( cd usr/man/man1 ; rm -rf cancel-cups.1.gz )
-( cd usr/man/man1 ; ln -sf lp.1.gz cancel-cups.1.gz )
 ( cd usr/man/man1 ; rm -rf lpr.1.gz )
 ( cd usr/man/man1 ; ln -sf lpr-cups.1.gz lpr.1.gz )
+( cd usr/man/man8 ; rm -rf cupsdisable.8.gz )
+( cd usr/man/man8 ; ln -sf cupsenable.8.gz cupsdisable.8.gz )
 ( cd usr/man/man8 ; rm -rf reject.8.gz )
 ( cd usr/man/man8 ; ln -sf accept.8.gz reject.8.gz )
-( cd usr/man/man8 ; rm -rf disable.8.gz )
-( cd usr/man/man8 ; ln -sf enable.8.gz disable.8.gz )
 ( cd usr/man/man8 ; rm -rf lpc.8.gz )
 ( cd usr/man/man8 ; ln -sf lpc-cups.8.gz lpc.8.gz )
 ( cd usr/sbin ; rm -rf lpc )
 ( cd usr/sbin ; ln -sf lpc-cups lpc )
+( cd usr/sbin ; rm -rf cupsenable )
+( cd usr/sbin ; ln -sf accept cupsenable )
+( cd usr/sbin ; rm -rf cupsdisable )
+( cd usr/sbin ; ln -sf accept cupsdisable )
 ( cd usr/sbin ; rm -rf reject )
 ( cd usr/sbin ; ln -sf accept reject )
